pub struct Character<'a, C> { /* private fields */ }Expand description
A single drawable character with configurable positioning.
Like Text, this implements Drawable for rendering on DrawTarget.
Useful for rendering individual characters with positioning and anchor support.
Examples
ⓘ
use embedded_graphics_profont::{Character, Anchor, WithAnchor};
use embedded_graphics::geometry::Point;
let ch = Character::new('A', Point::new(10, 10), &font, color)
.with_anchor(Anchor::MiddleCenter);
target.draw(&ch)?;Implementations
Sourceimpl<'a, C> Character<'a, C>where
C: PixelColor,
impl<'a, C> Character<'a, C>where
C: PixelColor,
Sourcepub fn new(ch: char, position: Point, font: &'a Font, color: C) -> Self
pub fn new(ch: char, position: Point, font: &'a Font, color: C) -> Self
Create a new character drawable.
The character will be positioned at the given point using the default
TopLeft anchor. Use with_anchor() to change the anchor point.
If the character is not supported by the font, it will simply not render.
Arguments
ch- Character to renderposition- Position of the anchor pointfont- Font to usecolor- Pixel color for the character